@@ -50,7 +50,7 @@ except:
 # FUNCTIONS
 def what_is_DSH():
 
-    print("-General Information- \n\n Description: Data Science Helper is a open source library that intends to save time \n and make important data science operations without any effort. \n Library Name: Data Science Helper \n Language: Python \n Version: 1.5.0 \n Field: Data science and Machine Learning \n Purpose: Helping with data science operations and save time. \n Used Libraries: Pandas, Numpy, Matplotlib, Seaborn, Scipy \n Github Link: https://github.com/bayhippo/Data-Science-Helper \n Author: Salih Albayrak \n First Creation Date: 7/31/2020 \n Documentation: https://github.com/bayhippo/Data-Science-Helper/wiki")    
+    print("-General Information- \n\n Description: Data Science Helper is a open source library that intends to save time \n and make important data science operations without any effort. \n Library Name: Data Science Helper \n Language: Python \n Version: 1.5.1 \n Field: Data science and Machine Learning \n Purpose: Helping with data science operations and save time. \n Used Libraries: Pandas, Numpy, Matplotlib, Seaborn, Scipy \n Github Link: https://github.com/bayhippo/Data-Science-Helper \n Author: Salih Albayrak \n First Creation Date: 7/31/2020 \n Documentation: https://github.com/bayhippo/Data-Science-Helper/wiki")    
 
     # what fucntion prints
     """
@@ -60,7 +60,7 @@ def what_is_DSH():
     and make important data science operations without any effort. 
     Library Name: Data Science Helper 
     Language: Python 
-    Version: 1.5.0 
+    Version: 1.5.1 
     Field: Data science and Machine Learning 
     Purpose: Helping with data science operations and save time. 
     Used Libraries: Pandas, Numpy, Matplotlib, Seaborn, Scipy 
@@ -513,8 +513,8 @@ def categorical_features_as_binary(data, features):
     for feature in features:
         feature_as_class = []
         most_frequent = data[feature].value_counts()[:1].sort_values(ascending=False)    
-        for point in feature: # iterating data points in the feature
-            if point == most_frequent:
+        for point in data[feature]: # iterating data points in the feature
+            if point == most_frequent.keys()[0]:
                 feature_as_class.append(1)
                 
             else:
